@@ -1,19 +1,19 @@
 
 #define HOST_CPU "sparc"
 #define HOST_VENDOR "sun"
-#define HOST_OS "solaris2.5"
+#define HOST_OS "solaris2.5.1"
 #define HOST_OS_NAME "solaris2"
-#define HOST_OS_VERSION "2.5"
+#define HOST_OS_VERSION "2.5.1"
 #define HOST_ARCH "sun4"
-#define HOST_NAME "starblazers.soscorp.com"
+#define HOST_NAME "lol.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Fri Jun  9 11:59:27 EDT 2000"
+#define CONFIG_DATE "Thu Jun  8 10:37:01 EDT 2000"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.4s6"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.5"
+#define HOST_HEADER_VERSION "2.5.1"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBPOSIX4 1
@@ -238,6 +238,7 @@
 #define HAVE_FS_TFS 1
 #define HAVE_FS_TMPFS 1
 #define HAVE_FS_UFS 1
+#define HAVE_SYS_FS_AUTOFS_H 1
 #define HAVE_FS_AUTOFS 1
 #define HAVE_FS_CACHEFS 1
 #define HAVE_AMU_FS_AUTO 1
